=====
PyXRF
=====

.. image:: https://img.shields.io/travis/NSLS-II/pyxrf.svg
        :target: https://travis-ci.org/NSLS-II/pyxrf

.. image:: https://img.shields.io/pypi/v/pyxrf.svg
        :target: https://pypi.python.org/pypi/pyxrf

.. image:: https://img.shields.io/codecov/c/github/NSLS-II/pyxrf
        :target: https://codecov.io/gh/NSLS-II/pyxrf

PyXRF is a python-based sophisticated fluorescence analysis package for
fitting and visualizing X-ray fluorescence data.

`PyXRF documentation <http://nsls-ii.github.io/PyXRF>`_

`Report an issue with PyXRF <https://github.com/NSLS-II/pyxrf/issues/new>`_

Installation instructions
-------------------------

PyXRF can be installed Linux, MacOS and Windows systems. Please refer
the `installation instructions <http://nsls-ii.github.io/PyXRF/installation.html>`_
in the `User's Manual <http://nsls-ii.github.io/PyXRF>`_.

Youtube tutorial
----------------

The Youtube tutorial for PyXRF can be found
`here <https://www.youtube.com/watch?v=2nFLccehaHI>`_.

Notes
-----

The core fitting functions are a part of the
`scikit-beam <https://github.com/scikit-beam/scikit-beam>`_
data analysis library for x-ray data analysis.
